.. rst-class:: detail

MoveToJoints
=======================

.. currentmodule:: compas_rrc

.. autoclass:: MoveToJoints

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~MoveToJoints.__init__
        ~MoveToJoints.from_msg
    
    